@@ -1,19 +1,19 @@
 #!/bin/bash
 
 # Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-# Copyright: (c) 2020/2021 Gianluca Pernigotto <jeanlucperni@gmail.com>
+# Copyleft - 2018/2023 Gianluca Pernigotto <jeanlucperni@gmail.com>
 # license: GPL3
-# Rev: August.20.2021
+# Rev: March.22.2022
 #
-# Make a new `videomass.po` file on '../../videomass3/locale'.
-# The previus videomass.po file will be overwrite with new one
-# incoming which will update latest strings for traslation .
+# Make a new `videomass.po` file on '../../videomass/locale'.
+# The previus videomass.po file will be overwrite with the new
+# one incoming which will update latest strings for traslation .
 
 PLATFORM=$(uname)  # command to show platform
 self="$(readlink -f -- $0)"  # this file
 here="${self%/*}"  # dirname of this file
 rootdir=$(dirname $here)  # base sources directory
-target="$rootdir/videomass3/locale"  # location to store new incoming
+target="$rootdir/videomass/locale"  # location to store new incoming
 
 cd $target
 
@@ -26,8 +26,9 @@ elif [ "$PLATFORM" = "Linux" ]; then
     XGETTEXT="xgettext"
 fi
 
-$XGETTEXT -d videomass "../vdms3.py" \
+$XGETTEXT -d videomass "../gui_app.py" \
 "../vdms_dialogs/audiodialogs.py" \
+"../vdms_dialogs/epilogue.py" \
 "../vdms_dialogs/filter_crop.py" \
 "../vdms_dialogs/filter_deinterlace.py" \
 "../vdms_dialogs/filter_denoisers.py" \
@@ -39,16 +40,19 @@ $XGETTEXT -d videomass "../vdms3.py" \
 "../vdms_dialogs/playlist_indexing.py" \
 "../vdms_dialogs/presets_addnew.py" \
 "../vdms_dialogs/set_timestamp.py" \
-"../vdms_dialogs/settings.py" \
+"../vdms_dialogs/preferences.py" \
+"../vdms_dialogs/videomass_check_version.py" \
+"../vdms_dialogs/ydl_mediainfo.py" \
+"../vdms_dialogs/mediainfo.py" \
+"../vdms_dialogs/widget_utils.py" \
+"../vdms_dialogs/showlogs.py" \
+"../vdms_dialogs/renamer.py" \
 "../vdms_frames/ffmpeg_conf.py" \
 "../vdms_frames/ffmpeg_codecs.py" \
 "../vdms_frames/ffmpeg_formats.py" \
 "../vdms_frames/shownormlist.py" \
 "../vdms_frames/while_playing.py" \
 "../vdms_frames/ffmpeg_search.py" \
-"../vdms_frames/mediainfo.py" \
-"../vdms_frames/showlogs.py" \
-"../vdms_frames/ydl_mediainfo.py" \
 "../vdms_io/checkup.py" \
 "../vdms_io/io_tools.py" \
 "../vdms_io/presets_manager_properties.py" \
@@ -62,20 +66,19 @@ $XGETTEXT -d videomass "../vdms3.py" \
 "../vdms_panels/presets_manager.py" \
 "../vdms_panels/textdrop.py" \
 "../vdms_panels/timeline.py" \
+"../vdms_panels/sequence_to_video.py" \
+"../vdms_panels/video_to_sequence.py" \
 "../vdms_threads/ffplay_file.py" \
-"../vdms_threads/ffprobe_parser.py" \
 "../vdms_threads/one_pass.py" \
 "../vdms_threads/picture_exporting.py" \
 "../vdms_threads/two_pass_ebu.py" \
 "../vdms_threads/two_pass.py" \
-"../vdms_threads/volumedetect.py" \
-"../vdms_threads/ydl_executable.py" \
-"../vdms_threads/youtubedlupdater.py"
+"../vdms_threads/slideshow.py" \
 
 if [ $? != 0 ]; then
     echo 'Failed!'
 else
     mv videomass.po videomass.pot
+    echo "A new 'videomass.pot' was created on: '${target}'"
     echo "Done!"
-    echo "'videomass.pot' was created on: '${target}'"
 fi
